# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AirtableField(UniversalBaseModel):
    """
    Airtable Field definition (column schema)
    """

    name: str = pydantic.Field()
    """
    Field name
    """

    type: str = pydantic.Field()
    """
    Field type (singleLineText, multilineText, number, singleSelect, multipleSelects, date, checkbox, url, email, phoneNumber, attachment, etc.)
    """

    options: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Field options (e.g., choices for select fields)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from ..core.serialization import FieldMetadata
from .big_query_table_reference import BigQueryTableReference
from .big_query_table_schema import BigQueryTableSchema


class BigQueryTable(UniversalBaseModel):
    """
    BigQuery table object - matches API format
    """

    table_reference: typing_extensions.Annotated[BigQueryTableReference, FieldMetadata(alias="tableReference")] = (
        pydantic.Field()
    )
    """
    Table reference
    """

    schema_: typing_extensions.Annotated[typing.Optional[BigQueryTableSchema], FieldMetadata(alias="schema")] = (
        pydantic.Field(default=None)
    )
    """
    Table schema
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Table description
    """

    num_rows: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="numRows")] = pydantic.Field(
        default=None
    )
    """
    Number of rows
    """

    creation_time: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="creationTime")] = (
        pydantic.Field(default=None)
    )
    """
    Creation timestamp
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(BigQueryTable)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .click_up_folder import ClickUpFolder
from .click_up_list import ClickUpList


class ClickUpSpace(UniversalBaseModel):
    """
    ClickUp Space object
    """

    name: str = pydantic.Field()
    """
    Space name
    """

    folders: typing.Optional[typing.List[ClickUpFolder]] = pydantic.Field(default=None)
    """
    Folders in this space
    """

    lists: typing.Optional[typing.List[ClickUpList]] = pydantic.Field(default=None)
    """
    Folderless lists in this space
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class SalesforceLead(UniversalBaseModel):
    """
    Salesforce Lead object with comprehensive field support
    """

    first_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="FirstName")] = pydantic.Field(
        default=None
    )
    """
    First name
    """

    last_name: typing_extensions.Annotated[str, FieldMetadata(alias="LastName")] = pydantic.Field()
    """
    Last name (required)
    """

    company: typing_extensions.Annotated[str, FieldMetadata(alias="Company")] = pydantic.Field()
    """
    Company name (required)
    """

    email: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Email")] = pydantic.Field(
        default=None
    )
    """
    Email address
    """

    phone: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Phone")] = pydantic.Field(
        default=None
    )
    """
    Phone number
    """

    mobile_phone: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="MobilePhone")] = (
        pydantic.Field(default=None)
    )
    """
    Mobile phone number
    """

    title: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Title")] = pydantic.Field(
        default=None
    )
    """
    Job title
    """

    status: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Status")] = pydantic.Field(
        default=None
    )
    """
    Lead status (e.g., Open, Contacted, Qualified)
    """

    lead_source: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="LeadSource")] = pydantic.Field(
        default=None
    )
    """
    Lead source (e.g., Web, Phone Inquiry, Partner Referral)
    """

    industry: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Industry")] = pydantic.Field(
        default=None
    )
    """
    Industry (e.g., Technology, Healthcare, Finance)
    """

    rating: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Rating")] = pydantic.Field(
        default=None
    )
    """
    Lead rating (e.g., Hot, Warm, Cold)
    """

    street: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Street")] = pydantic.Field(
        default=None
    )
    """
    Street address
    """

    city: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="City")] = pydantic.Field(default=None)
    """
    City
    """

    state: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="State")] = pydantic.Field(
        default=None
    )
    """
    State/province
    """

    postal_code: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="PostalCode")] = pydantic.Field(
        default=None
    )
    """
    Postal code
    """

    country: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Country")] = pydantic.Field(
        default=None
    )
    """
    Country
    """

    website: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Website")] = pydantic.Field(
        default=None
    )
    """
    Website URL
    """

    description: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Description")] = pydantic.Field(
        default=None
    )
    """
    Lead description
    """

    number_of_employees: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="NumberOfEmployees")] = (
        pydantic.Field(default=None)
    )
    """
    Number of employees
    """

    annual_revenue: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="AnnualRevenue")] = (
        pydantic.Field(default=None)
    )
    """
    Annual revenue
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs
from .one_drive_file import OneDriveFile


class OneDriveFolder(UniversalBaseModel):
    """
    OneDrive Folder object
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Folder ID (read-only, set by OneDrive)
    """

    name: str = pydantic.Field()
    """
    Folder name
    """

    folders: typing.Optional[typing.List["OneDriveFolder"]] = pydantic.Field(default=None)
    """
    List of subfolders
    """

    files: typing.Optional[typing.List[OneDriveFile]] = pydantic.Field(default=None)
    """
    List of files in the folder
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(OneDriveFolder)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs


class ConfluenceSpace(UniversalBaseModel):
    """
    Confluence Space object
    """

    key: str = pydantic.Field()
    """
    Space key (e.g., DS)
    """

    name: str = pydantic.Field()
    """
    Space name
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Space description
    """

    pages: typing.Optional[typing.List["ConfluencePage"]] = pydantic.Field(default=None)
    """
    Root pages in this space
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .confluence_page import ConfluencePage  # noqa: E402, I001

update_forward_refs(ConfluenceSpace)



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.delete_user_response import DeleteUserResponse
from ..types.get_all_users_response import GetAllUsersResponse
from ..types.get_user_auth_response import GetUserAuthResponse
from ..types.get_user_integrations_response import GetUserIntegrationsResponse
from ..types.get_user_response import GetUserResponse
from ..types.http_validation_error import HttpValidationError
from ..types.mcp_server_name import McpServerName
from ..types.status_response import StatusResponse
from .types.set_user_auth_request_auth_data import SetUserAuthRequestAuthData

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawUserClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_user_integrations(
        self, user_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[GetUserIntegrationsResponse]:
        """
        Get all available integrations (MCP server names) by user ID.
        Returns a list of integration names as McpServerName types.

        Parameters
        ----------
        user_id : str
            The external user ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetUserIntegrationsResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"user/{jsonable_encoder(user_id)}/integrations",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetUserIntegrationsResponse,
                    parse_obj_as(
                        type_=GetUserIntegrationsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_user_by_user_id(
        self, user_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[GetUserResponse]:
        """
        Get user information by user_id.

        Parameters
        ----------
        user_id : str
            The identifier for the user to fetch.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetUserResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"user/{jsonable_encoder(user_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetUserResponse,
                    parse_obj_as(
                        type_=GetUserResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete_user_by_user_id(
        self, user_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[DeleteUserResponse]:
        """
        Delete a user and all associated data by user_id.
        Users cannot delete their own accounts.
        This operation will permanently remove all user data.

        Parameters
        ----------
        user_id : str
            The identifier for the user to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DeleteUserResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"user/{jsonable_encoder(user_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DeleteUserResponse,
                    parse_obj_as(
                        type_=DeleteUserResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_all_users(
        self,
        *,
        page_size: typing.Optional[int] = None,
        page_number: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[GetAllUsersResponse]:
        """
        Retrieve all users that have been created under your account, with support for pagination.

        Parameters
        ----------
        page_size : typing.Optional[int]
            Number of results per page (max 1000)

        page_number : typing.Optional[int]
            Page number to retrieve (starting from 1)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetAllUsersResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "user/",
            method="GET",
            params={
                "page_size": page_size,
                "page_number": page_number,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetAllUsersResponse,
                    parse_obj_as(
                        type_=GetAllUsersResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def set_user_auth(
        self,
        *,
        user_id: str,
        server_name: McpServerName,
        auth_data: SetUserAuthRequestAuthData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[StatusResponse]:
        """
        Sets authentication data for a specific integration for a user.

        Accepts either API key authentication or general authentication data.
        This updates the auth_metadata for the specified user's integration instance.

        Parameters
        ----------
        user_id : str
            The unique identifier for the user

        server_name : McpServerName
            The name of the MCP server to set authentication for (e.g., 'GitHub', 'Jira')

        auth_data : SetUserAuthRequestAuthData
            Authentication data

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[StatusResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "user/set-auth",
            method="POST",
            json={
                "userId": user_id,
                "serverName": server_name,
                "authData": convert_and_respect_annotation_metadata(
                    object_=auth_data, annotation=SetUserAuthRequestAuthData, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StatusResponse,
                    parse_obj_as(
                        type_=StatusResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_user_auth(
        self, user_id: str, server_name: McpServerName, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[GetUserAuthResponse]:
        """
        Retrieves authentication data for a specific integration for a user.

        Returns the authentication data if available, along with authentication status.
        Includes token refresh handling if needed.

        Parameters
        ----------
        user_id : str
            The identifier for the user

        server_name : McpServerName
            The name of the MCP server (e.g., 'GitHub', 'Jira')

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetUserAuthResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"user/{jsonable_encoder(user_id)}/auth/{jsonable_encoder(server_name)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetUserAuthResponse,
                    parse_obj_as(
                        type_=GetUserAuthResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete_user_auth(
        self, user_id: str, server_name: McpServerName, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[StatusResponse]:
        """
        Deletes authentication data for a specific integration for a user.

        This will clear the stored authentication credentials, effectively unauthenticating the integration.

        Parameters
        ----------
        user_id : str
            The unique identifier for the user

        server_name : McpServerName
            The name of the MCP server to delete authentication for (e.g., 'github', 'jira')

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[StatusResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"user/{jsonable_encoder(user_id)}/auth/{jsonable_encoder(server_name)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StatusResponse,
                    parse_obj_as(
                        type_=StatusResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawUserClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_user_integrations(
        self, user_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[GetUserIntegrationsResponse]:
        """
        Get all available integrations (MCP server names) by user ID.
        Returns a list of integration names as McpServerName types.

        Parameters
        ----------
        user_id : str
            The external user ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetUserIntegrationsResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"user/{jsonable_encoder(user_id)}/integrations",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetUserIntegrationsResponse,
                    parse_obj_as(
                        type_=GetUserIntegrationsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_user_by_user_id(
        self, user_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[GetUserResponse]:
        """
        Get user information by user_id.

        Parameters
        ----------
        user_id : str
            The identifier for the user to fetch.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetUserResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"user/{jsonable_encoder(user_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetUserResponse,
                    parse_obj_as(
                        type_=GetUserResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete_user_by_user_id(
        self, user_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[DeleteUserResponse]:
        """
        Delete a user and all associated data by user_id.
        Users cannot delete their own accounts.
        This operation will permanently remove all user data.

        Parameters
        ----------
        user_id : str
            The identifier for the user to delete.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DeleteUserResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"user/{jsonable_encoder(user_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DeleteUserResponse,
                    parse_obj_as(
                        type_=DeleteUserResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_all_users(
        self,
        *,
        page_size: typing.Optional[int] = None,
        page_number: typing.Optional[int] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[GetAllUsersResponse]:
        """
        Retrieve all users that have been created under your account, with support for pagination.

        Parameters
        ----------
        page_size : typing.Optional[int]
            Number of results per page (max 1000)

        page_number : typing.Optional[int]
            Page number to retrieve (starting from 1)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetAllUsersResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "user/",
            method="GET",
            params={
                "page_size": page_size,
                "page_number": page_number,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetAllUsersResponse,
                    parse_obj_as(
                        type_=GetAllUsersResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def set_user_auth(
        self,
        *,
        user_id: str,
        server_name: McpServerName,
        auth_data: SetUserAuthRequestAuthData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[StatusResponse]:
        """
        Sets authentication data for a specific integration for a user.

        Accepts either API key authentication or general authentication data.
        This updates the auth_metadata for the specified user's integration instance.

        Parameters
        ----------
        user_id : str
            The unique identifier for the user

        server_name : McpServerName
            The name of the MCP server to set authentication for (e.g., 'GitHub', 'Jira')

        auth_data : SetUserAuthRequestAuthData
            Authentication data

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[StatusResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "user/set-auth",
            method="POST",
            json={
                "userId": user_id,
                "serverName": server_name,
                "authData": convert_and_respect_annotation_metadata(
                    object_=auth_data, annotation=SetUserAuthRequestAuthData, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StatusResponse,
                    parse_obj_as(
                        type_=StatusResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_user_auth(
        self, user_id: str, server_name: McpServerName, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[GetUserAuthResponse]:
        """
        Retrieves authentication data for a specific integration for a user.

        Returns the authentication data if available, along with authentication status.
        Includes token refresh handling if needed.

        Parameters
        ----------
        user_id : str
            The identifier for the user

        server_name : McpServerName
            The name of the MCP server (e.g., 'GitHub', 'Jira')

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetUserAuthResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"user/{jsonable_encoder(user_id)}/auth/{jsonable_encoder(server_name)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetUserAuthResponse,
                    parse_obj_as(
                        type_=GetUserAuthResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete_user_auth(
        self, user_id: str, server_name: McpServerName, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[StatusResponse]:
        """
        Deletes authentication data for a specific integration for a user.

        This will clear the stored authentication credentials, effectively unauthenticating the integration.

        Parameters
        ----------
        user_id : str
            The unique identifier for the user

        server_name : McpServerName
            The name of the MCP server to delete authentication for (e.g., 'github', 'jira')

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[StatusResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"user/{jsonable_encoder(user_id)}/auth/{jsonable_encoder(server_name)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    StatusResponse,
                    parse_obj_as(
                        type_=StatusResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .asana_story import AsanaStory


class AsanaTask(UniversalBaseModel):
    """
    Asana Task object
    """

    gid: typing.Optional[str] = pydantic.Field(default=None)
    """
    Globally unique identifier of the resource (read-only, set by Asana)
    """

    name: str = pydantic.Field()
    """
    Task name
    """

    notes: typing.Optional[str] = pydantic.Field(default=None)
    """
    Task notes/description
    """

    completed: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether task is completed
    """

    assignee: typing.Optional[str] = pydantic.Field(default=None)
    """
    User GID assigned to task
    """

    due_on: typing.Optional[str] = pydantic.Field(default=None)
    """
    Due date (YYYY-MM-DD)
    """

    due_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    Due datetime (ISO 8601)
    """

    start_on: typing.Optional[str] = pydantic.Field(default=None)
    """
    Start date (YYYY-MM-DD)
    """

    stories: typing.Optional[typing.List[AsanaStory]] = pydantic.Field(default=None)
    """
    Stories (comments) on this task
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .linear_project import LinearProject


class LinearData(UniversalBaseModel):
    """
    Complete Linear sandbox data structure.

    Relational structure for initialization:
    - Projects contain Issues
    - Issues contain Comments
    """

    projects: typing.Optional[typing.List[LinearProject]] = pydantic.Field(default=None)
    """
    List of projects with their issues. At most 50 projects can be included.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class HubSpotDeal(UniversalBaseModel):
    """
    HubSpot Deal object.
    Can be associated with: Contacts, Companies.
    """

    deal_name: str = pydantic.Field()
    """
    Deal name
    """

    amount: typing.Optional[str] = pydantic.Field(default=None)
    """
    Deal amount
    """

    deal_stage: typing.Optional[str] = pydantic.Field(default=None)
    """
    Deal stage
    """

    pipeline: typing.Optional[str] = pydantic.Field(default=None)
    """
    Deal pipeline
    """

    close_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    Expected close date
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .click_up_comment import ClickUpComment


class ClickUpTask(UniversalBaseModel):
    """
    ClickUp Task object
    """

    name: str = pydantic.Field()
    """
    Task name
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Task description
    """

    priority: typing.Optional[int] = pydantic.Field(default=None)
    """
    Task priority (1-4)
    """

    comments: typing.Optional[typing.List[ClickUpComment]] = pydantic.Field(default=None)
    """
    Comments on this task
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.mcp_server_name import McpServerName

DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem = typing.Union[
    McpServerName, typing.Literal["ALL"]
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GoogleCalendarEventDateTime(UniversalBaseModel):
    """
    Event date/time with timezone support
    """

    date_time: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="dateTime")] = pydantic.Field(
        default=None
    )
    """
    RFC3339 timestamp (e.g., 2025-12-01T09:00:00-07:00)
    """

    date: typing.Optional[str] = pydantic.Field(default=None)
    """
    All-day event date in YYYY-MM-DD format
    """

    time_zone: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="timeZone")] = pydantic.Field(
        default=None
    )
    """
    IANA timezone (e.g., America/Los_Angeles)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class LogEntry(UniversalBaseModel):
    """
    Cloud Logging log entry - matches API format
    """

    log_name: typing_extensions.Annotated[str, FieldMetadata(alias="logName")] = pydantic.Field()
    """
    Log name
    """

    text_payload: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="textPayload")] = (
        pydantic.Field(default=None)
    )
    """
    Text payload
    """

    json_payload: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="jsonPayload")
    ] = pydantic.Field(default=None)
    """
    JSON payload
    """

    severity: typing.Optional[str] = pydantic.Field(default=None)
    """
    Log severity (DEBUG, INFO, WARNING, ERROR, CRITICAL)
    """

    timestamp: typing.Optional[str] = pydantic.Field(default=None)
    """
    Entry timestamp
    """

    insert_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="insertId")] = pydantic.Field(
        default=None
    )
    """
    Unique insert ID
    """

    resource: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Monitored resource
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .shopify_customer import ShopifyCustomer
from .shopify_product import ShopifyProduct


class ShopifyData(UniversalBaseModel):
    """
    Complete Shopify sandbox data structure

    Note: Orders are created automatically by the sandbox based on products and customers.
    The initialize method will generate orders that link customers to products.
    """

    products: typing.Optional[typing.List[ShopifyProduct]] = pydantic.Field(default=None)
    """
    List of products to create
    """

    customers: typing.Optional[typing.List[ShopifyCustomer]] = pydantic.Field(default=None)
    """
    List of customers to create
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .shopify_product_variant import ShopifyProductVariant


class ShopifyProduct(UniversalBaseModel):
    """
    Shopify product data

    Attributes:
        title: Product title/name
        body_html: HTML description of the product
        vendor: Product vendor/brand name
        product_type: Category/type of product
        status: Product status (active, draft, archived)
        variants: List of product variants (at least one required)
    """

    title: str = pydantic.Field()
    """
    Product title/name
    """

    body_html: typing.Optional[str] = pydantic.Field(default=None)
    """
    HTML description of the product
    """

    vendor: str = pydantic.Field()
    """
    Product vendor/brand name
    """

    product_type: str = pydantic.Field()
    """
    Category/type of product
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    Product status (active, draft, archived)
    """

    variants: typing.List[ShopifyProductVariant] = pydantic.Field()
    """
    List of product variants
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CloseOpportunity(UniversalBaseModel):
    """
    Close Opportunity object - child of Lead
    """

    note: str = pydantic.Field()
    """
    Opportunity note/description
    """

    value: typing.Optional[int] = pydantic.Field(default=None)
    """
    Opportunity value in cents
    """

    confidence: typing.Optional[int] = pydantic.Field(default=None)
    """
    Confidence percentage (0-100)
    """

    value_period: typing.Optional[str] = pydantic.Field(default=None)
    """
    Value period (e.g., 'one_time', 'monthly', 'annual')
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .salesforce_account import SalesforceAccount
from .salesforce_campaign import SalesforceCampaign
from .salesforce_case import SalesforceCase
from .salesforce_contact import SalesforceContact
from .salesforce_lead import SalesforceLead
from .salesforce_opportunity import SalesforceOpportunity


class SalesforceData(UniversalBaseModel):
    """
    Complete Salesforce sandbox data structure with all supported objects
    """

    accounts: typing.Optional[typing.List[SalesforceAccount]] = pydantic.Field(default=None)
    """
    List of Salesforce accounts
    """

    contacts: typing.Optional[typing.List[SalesforceContact]] = pydantic.Field(default=None)
    """
    List of Salesforce contacts
    """

    opportunities: typing.Optional[typing.List[SalesforceOpportunity]] = pydantic.Field(default=None)
    """
    List of Salesforce opportunities
    """

    leads: typing.Optional[typing.List[SalesforceLead]] = pydantic.Field(default=None)
    """
    List of Salesforce leads
    """

    cases: typing.Optional[typing.List[SalesforceCase]] = pydantic.Field(default=None)
    """
    List of Salesforce cases
    """

    campaigns: typing.Optional[typing.List[SalesforceCampaign]] = pydantic.Field(default=None)
    """
    List of Salesforce campaigns
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .moneybird_invoice_detail import MoneybirdInvoiceDetail


class MoneybirdSalesInvoice(UniversalBaseModel):
    """
    Moneybird sales invoice - API format

    Note: During initialization, contact_id will be automatically assigned based on
    the contacts created. Invoice dates will be calculated dynamically.

    Attributes:
        reference: Invoice reference number
        currency: Currency code (e.g., 'EUR')
        prices_are_incl_tax: Whether prices include tax
        state: Invoice state (draft, open, paid)
        details: List of invoice line items
    """

    reference: str = pydantic.Field()
    """
    Invoice reference number
    """

    currency: typing.Optional[str] = pydantic.Field(default=None)
    """
    Currency code
    """

    prices_are_incl_tax: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether prices include tax
    """

    state: typing.Optional[str] = pydantic.Field(default=None)
    """
    Invoice state (draft, open, paid)
    """

    details: typing.List[MoneybirdInvoiceDetail] = pydantic.Field()
    """
    Invoice line items
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .big_query_dataset_reference import BigQueryDatasetReference


class BigQueryDataset(UniversalBaseModel):
    """
    BigQuery dataset object - matches API format
    """

    dataset_reference: typing_extensions.Annotated[
        BigQueryDatasetReference, FieldMetadata(alias="datasetReference")
    ] = pydantic.Field()
    """
    Dataset reference
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Dataset description
    """

    location: typing.Optional[str] = pydantic.Field(default=None)
    """
    Dataset location
    """

    creation_time: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="creationTime")] = (
        pydantic.Field(default=None)
    )
    """
    Creation timestamp
    """

    last_modified_time: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="lastModifiedTime")] = (
        pydantic.Field(default=None)
    )
    """
    Last modified timestamp
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .google_sheets_row_data import GoogleSheetsRowData


class GoogleSheetsGridData(UniversalBaseModel):
    """
    Grid data for a sheet
    """

    start_row: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="startRow")] = pydantic.Field(
        default=None
    )
    """
    Starting row index
    """

    start_column: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="startColumn")] = (
        pydantic.Field(default=None)
    )
    """
    Starting column index
    """

    row_data: typing_extensions.Annotated[
        typing.Optional[typing.List[GoogleSheetsRowData]], FieldMetadata(alias="rowData")
    ] = pydantic.Field(default=None)
    """
    Row data with values array
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class OutlookMailMessage(UniversalBaseModel):
    """
    Outlook Mail Message object
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Message ID (read-only, set by Outlook)
    """

    subject: str = pydantic.Field()
    """
    Email subject
    """

    body: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Email body with content and contentType
    """

    from_: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]], FieldMetadata(alias="from")
    ] = pydantic.Field(default=None)
    """
    From address with emailAddress object
    """

    to_recipients: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of recipient email addresses
    """

    cc_recipients: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of CC recipient email addresses
    """

    is_read: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether the message has been read
    """

    received_date_time: typing.Optional[str] = pydantic.Field(default=None)
    """
    Date and time the message was received
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class SalesforceAccount(UniversalBaseModel):
    """
    Salesforce Account object with comprehensive field support
    """

    name: typing_extensions.Annotated[str, FieldMetadata(alias="Name")] = pydantic.Field()
    """
    Account name (required)
    """

    industry: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Industry")] = pydantic.Field(
        default=None
    )
    """
    Industry (e.g., Technology, Healthcare, Finance)
    """

    type: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Type")] = pydantic.Field(default=None)
    """
    Account type (e.g., Customer, Prospect, Partner)
    """

    phone: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Phone")] = pydantic.Field(
        default=None
    )
    """
    Phone number
    """

    website: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Website")] = pydantic.Field(
        default=None
    )
    """
    Website URL
    """

    annual_revenue: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="AnnualRevenue")] = (
        pydantic.Field(default=None)
    )
    """
    Annual revenue
    """

    number_of_employees: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="NumberOfEmployees")] = (
        pydantic.Field(default=None)
    )
    """
    Number of employees
    """

    billing_street: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BillingStreet")] = (
        pydantic.Field(default=None)
    )
    """
    Billing street address
    """

    billing_city: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BillingCity")] = (
        pydantic.Field(default=None)
    )
    """
    Billing city
    """

    billing_state: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BillingState")] = (
        pydantic.Field(default=None)
    )
    """
    Billing state/province
    """

    billing_postal_code: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BillingPostalCode")] = (
        pydantic.Field(default=None)
    )
    """
    Billing postal code
    """

    billing_country: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="BillingCountry")] = (
        pydantic.Field(default=None)
    )
    """
    Billing country
    """

    description: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Description")] = pydantic.Field(
        default=None
    )
    """
    Account description
    """

    rating: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Rating")] = pydantic.Field(
        default=None
    )
    """
    Account rating (e.g., Hot, Warm, Cold)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.bad_request_error import BadRequestError
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.azure_ado_auth_success_response import AzureAdoAuthSuccessResponse
from ..types.http_validation_error import HttpValidationError


class RawTeamsOauthClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def refresh_token(
        self, *, instance_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[AzureAdoAuthSuccessResponse]:
        """
        Parameters
        ----------
        instance_id : str
            Instance ID for which to refresh the token

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[AzureAdoAuthSuccessResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "oauth/teams/refresh_token",
            method="POST",
            params={
                "instance_id": instance_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AzureAdoAuthSuccessResponse,
                    parse_obj_as(
                        type_=AzureAdoAuthSuccessResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawTeamsOauthClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def refresh_token(
        self, *, instance_id: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[AzureAdoAuthSuccessResponse]:
        """
        Parameters
        ----------
        instance_id : str
            Instance ID for which to refresh the token

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[AzureAdoAuthSuccessResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "oauth/teams/refresh_token",
            method="POST",
            params={
                "instance_id": instance_id,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AzureAdoAuthSuccessResponse,
                    parse_obj_as(
                        type_=AzureAdoAuthSuccessResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .jira_comment import JiraComment


class JiraIssue(UniversalBaseModel):
    """
    Jira Issue object
    """

    summary: str = pydantic.Field()
    """
    Issue summary/title
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Issue description
    """

    issue_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Issue type (Task, Bug, Story, etc.)
    """

    priority: typing.Optional[str] = pydantic.Field(default=None)
    """
    Issue priority (Highest, High, Medium, Low, Lowest)
    """

    sprint_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the sprint this issue belongs to (for initialization)
    """

    comments: typing.Optional[typing.List[JiraComment]] = pydantic.Field(default=None)
    """
    Comments on this issue
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .user_info import UserInfo


class GetAllUsersResponse(UniversalBaseModel):
    users: typing.List[UserInfo] = pydantic.Field()
    """
    List of users
    """

    total_count: typing_extensions.Annotated[int, FieldMetadata(alias="totalCount")] = pydantic.Field()
    """
    Total number of users across all pages
    """

    page: int = pydantic.Field()
    """
    Current page number
    """

    page_size: typing_extensions.Annotated[int, FieldMetadata(alias="pageSize")] = pydantic.Field()
    """
    Number of results per page
    """

    total_pages: typing_extensions.Annotated[int, FieldMetadata(alias="totalPages")] = pydantic.Field()
    """
    Total number of pages
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class SalesforceOpportunity(UniversalBaseModel):
    """
    Salesforce Opportunity object with comprehensive field support
    """

    name: typing_extensions.Annotated[str, FieldMetadata(alias="Name")] = pydantic.Field()
    """
    Opportunity name (required)
    """

    stage_name: typing_extensions.Annotated[str, FieldMetadata(alias="StageName")] = pydantic.Field()
    """
    Sales stage (required, e.g., Prospecting, Qualification, Closed Won)
    """

    close_date: typing_extensions.Annotated[str, FieldMetadata(alias="CloseDate")] = pydantic.Field()
    """
    Close date (required, format: YYYY-MM-DD)
    """

    amount: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="Amount")] = pydantic.Field(
        default=None
    )
    """
    Opportunity amount
    """

    probability: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="Probability")] = pydantic.Field(
        default=None
    )
    """
    Probability of closing (0-100)
    """

    account_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="AccountId")] = pydantic.Field(
        default=None
    )
    """
    Related account ID (18-char Salesforce ID)
    """

    type: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Type")] = pydantic.Field(default=None)
    """
    Opportunity type (e.g., New Business, Existing Business)
    """

    lead_source: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="LeadSource")] = pydantic.Field(
        default=None
    )
    """
    Lead source (e.g., Web, Phone Inquiry, Partner Referral)
    """

    next_step: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="NextStep")] = pydantic.Field(
        default=None
    )
    """
    Next step in the sales process
    """

    description: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Description")] = pydantic.Field(
        default=None
    )
    """
    Opportunity description
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .dropbox_file import DropboxFile


class DropboxData(UniversalBaseModel):
    """
    Complete Dropbox sandbox data structure

    Describes the folder and file structure to be created in the sandbox.
    Folders are created in the order specified, and files are uploaded after
    all folders have been created.

    Note: The root folder /SandboxTest is always created first automatically.
    Additional folders should be nested within /SandboxTest.
    """

    folders: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of folder paths to create (e.g., ['/SandboxTest', '/SandboxTest/Documents'])
    """

    files: typing.Optional[typing.List[DropboxFile]] = pydantic.Field(default=None)
    """
    List of files to create with their content
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class ShopifyAddress(UniversalBaseModel):
    """
    Customer address information

    Attributes:
        address1: Street address line 1 (optional - may not be present in API response)
        city: City name (optional - may not be present in API response)
        province: State/province code (optional - may not be present in API response)
        zip: Postal/ZIP code (optional - may not be present in API response)
        country: Country code (e.g., 'US') (optional - may not be present in API response)
    """

    address1: typing.Optional[str] = pydantic.Field(default=None)
    """
    Street address line 1
    """

    city: typing.Optional[str] = pydantic.Field(default=None)
    """
    City name
    """

    province: typing.Optional[str] = pydantic.Field(default=None)
    """
    State/province code
    """

    zip: typing.Optional[str] = pydantic.Field(default=None)
    """
    Postal/ZIP code
    """

    country: typing.Optional[str] = pydantic.Field(default=None)
    """
    Country code (e.g., 'US')
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class WordPressPost(UniversalBaseModel):
    """
    WordPress post data for creation/update

    Attributes:
        title: Post title
        content: Post content (HTML or plain text)
        status: Post status (draft, publish, private, pending)
        excerpt: Post excerpt/summary (optional)
        categories: List of category names (optional, created if not exist)
        tags: List of tag names (optional, created if not exist)
        featured_image: URL to featured image (optional)
        date: Post publish date in ISO format (optional)
        format: Post format (standard, aside, gallery, etc.) (optional)
    """

    title: str = pydantic.Field()
    """
    Post title
    """

    content: str = pydantic.Field()
    """
    Post content (HTML or plain text)
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    Post status: draft, publish, private, pending, trash
    """

    excerpt: typing.Optional[str] = pydantic.Field(default=None)
    """
    Post excerpt/summary
    """

    categories: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of category names
    """

    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of tag names
    """

    featured_image: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL to featured image
    """

    date: typing.Optional[str] = pydantic.Field(default=None)
    """
    Post publish date in ISO format (e.g., 2025-01-15T10:00:00)
    """

    format: typing.Optional[str] = pydantic.Field(default=None)
    """
    Post format: standard, aside, gallery, link, image, quote, status, video, audio, chat
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class OutlookCalendarEvent(UniversalBaseModel):
    """
    Outlook Calendar Event object
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Event ID (read-only, set by Outlook)
    """

    subject: str = pydantic.Field()
    """
    Event subject/title
    """

    start: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Start time with dateTime and timeZone
    """

    end: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    End time with dateTime and timeZone
    """

    location: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Location object with displayName
    """

    attendees: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of attendee email addresses (e.g., ['user@example.com'])
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .notion_data_source import NotionDataSource


class NotionDatabase(UniversalBaseModel):
    """
    Notion Database object - container for data sources.

    Databases organize structured data and can contain multiple data sources.
    Each data source represents a table with its own schema.
    """

    title: str = pydantic.Field()
    """
    Database title
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Database description
    """

    icon: typing.Optional[str] = pydantic.Field(default=None)
    """
    Database icon (emoji or external URL)
    """

    data_sources: typing.Optional[typing.List[NotionDataSource]] = pydantic.Field(default=None)
    """
    Data sources within this database
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class HubSpotContact(UniversalBaseModel):
    """
    HubSpot Contact object.
    Can be associated with: Companies.
    """

    firstname: str = pydantic.Field()
    """
    Contact first name
    """

    lastname: str = pydantic.Field()
    """
    Contact last name
    """

    email: str = pydantic.Field()
    """
    Contact email address
    """

    phone: typing.Optional[str] = pydantic.Field(default=None)
    """
    Contact phone number
    """

    job_title: typing.Optional[str] = pydantic.Field(default=None)
    """
    Contact job title
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel, update_forward_refs


class OneDriveData(UniversalBaseModel):
    """
    Complete OneDrive sandbox data structure
    """

    root: "OneDriveFolder" = pydantic.Field()
    """
    Root folder containing all subfolders and files
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .one_drive_folder import OneDriveFolder  # noqa: E402, I001

update_forward_refs(OneDriveData)
